## Super heroes

### Variables

- name = super hero name
- alignment = good or bad character
- gender = male or female
- publisher = name of the comic publisher

<a href="http://stat545-ubc.github.io/bit001_dplyr-cheatsheet.html" target="_blank">Source</a>
